==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume.md <==
# AwsStorageGatewayNonCachedVolume


```text
aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume
```

```text
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')
```



| Illustration | AwsStorageGatewayNonCachedVolume | AwsStorageGatewayNonCachedVolumeCard | AwsStorageGatewayNonCachedVolumeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume.png) | ![illustration for AwsStorageGatewayNonCachedVolume](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume.Local.png) | ![illustration for AwsStorageGatewayNonCachedVolumeCard](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolumeCard.Local.png) | ![illustration for AwsStorageGatewayNonCachedVolumeGroup](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolumeGroup.Local.png) |




## AwsStorageGatewayNonCachedVolume

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolume
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolume('AwsStorageGatewayNonCachedVolume', 'Aws Storage Gateway Non Cached Volume', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolume
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolume('AwsStorageGatewayNonCachedVolume', 'Aws Storage Gateway Non Cached Volume', 'an optional tech label')
@enduml
```

## AwsStorageGatewayNonCachedVolumeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeCard('AwsStorageGatewayNonCachedVolumeCard', 'Aws Storage Gateway Non Cached Volume Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeCard('AwsStorageGatewayNonCachedVolumeCard', 'Aws Storage Gateway Non Cached Volume Card', 'an optional description')
@enduml
```

## AwsStorageGatewayNonCachedVolumeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeGroup('AwsStorageGatewayNonCachedVolumeGroup', 'Aws Storage Gateway Non Cached Volume Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeGroup('AwsStorageGatewayNonCachedVolumeGroup', 'Aws Storage Gateway Non Cached Volume Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume.md <==
# AwsStorageGatewayNonCachedVolume


```text
aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume
```

```text
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')
```



| Illustration | AwsStorageGatewayNonCachedVolume | AwsStorageGatewayNonCachedVolumeCard | AwsStorageGatewayNonCachedVolumeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume.png) | ![illustration for AwsStorageGatewayNonCachedVolume](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume.Local.png) | ![illustration for AwsStorageGatewayNonCachedVolumeCard](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolumeCard.Local.png) | ![illustration for AwsStorageGatewayNonCachedVolumeGroup](../../../aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolumeGroup.Local.png) |




## AwsStorageGatewayNonCachedVolume

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolume
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolume('AwsStorageGatewayNonCachedVolume', 'Aws Storage Gateway Non Cached Volume', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolume
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolume('AwsStorageGatewayNonCachedVolume', 'Aws Storage Gateway Non Cached Volume', 'an optional tech label')
@enduml
```

## AwsStorageGatewayNonCachedVolumeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeCard('AwsStorageGatewayNonCachedVolumeCard', 'Aws Storage Gateway Non Cached Volume Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeCard('AwsStorageGatewayNonCachedVolumeCard', 'Aws Storage Gateway Non Cached Volume Card', 'an optional description')
@enduml
```

## AwsStorageGatewayNonCachedVolumeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeGroup('AwsStorageGatewayNonCachedVolumeGroup', 'Aws Storage Gateway Non Cached Volume Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayNonCachedVolumeGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayNonCachedVolume')

' renders the element
AwsStorageGatewayNonCachedVolumeGroup('AwsStorageGatewayNonCachedVolumeGroup', 'Aws Storage Gateway Non Cached Volume Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
